# Chemises 

> Chemises - a lightweight undergarment made of linen

This is a library of helper functions and basic module layers for uses with  the `flax.linen` 


## Set Up
The easiest way is to clone the repo and install it. 
Hopefully if I have the config set up it should install all the deps
```shell
git clone 
pip install -e .
```

### Project Layout
- `/src` - all the lib code, everything needed to created and run the models, data pipelines etc.